@@ -86,9 +86,9 @@ class Dict_tiny(cli.Application):
         else:
             if_sentence = True if len(wordFinal) > 1 or len(wordFinal) == 1 and len(wordFinal[0]) > 4 and is_alphabet(
                 wordFinal[0]) == 'cn' else False
-            if_english = True if len(wordFinal) > 1 or len(wordFinal) == 1 and is_alphabet(
-                wordFinal[0]) == 'en' else False
             wordFinal = " ".join(wordFinal)
+            if_english = True if is_alphabet(wordFinal) == 'en' else False
+
             if not self.target_language:
                 if self.if_google_api:
                     self.target_language = "zh" if if_english else "en"
